import {Request, Response} from 'express';
import {Draft} from '../../models';

export default async (req: Request, res: Response) => {
    const id = Draft.ID_REG.test(req.params.id) && req.params.id;
    if (!id) {
        res.status(400).send({error: 'Missing or incorrect draft id'});
        return;
    }

    const draft = await Draft
        .query()
        .where({id})
        .first();

    if (!draft) {
        res.status(404).send({error: 'Draft not found'});
        return;
    }

    if (draft.userId !== req.userInfo.id) {
        res.status(403).send({error: 'Authorization required'});
        return;
    }

    const result = await Draft
        .query()
        .where({id})
        .first()
        .delete()
        .returning('id');

    res.send(result);
};
