import {Request, Response} from 'express';
import {db, Draft} from '../../models';

export default async (req: Request, res: Response) => {
    const id = Draft.ID_REG.test(req.params.id) && req.params.id;
    if (!id) {
        res.status(400).send({error: 'Missing or incorrect draft id'});
        return;
    }

    const draft = await Draft
        .query()
        .select('drafts.id', 'drafts.title', 'drafts.content', 'drafts.createdAt', 'drafts.updatedAt', 'users.username as author')
        .innerJoin('users', 'drafts.userId', 'users.id')
        .where({'drafts.id': id})
        .first();

    if (draft) {
        res.send(draft);
    } else {
        res.status(404).send({error: 'Draft not found'});
    }
};
