import {Request, Response} from 'express';
import {db, Draft} from '../../models';

export default async (req: Request, res: Response) => {
    const id = Draft.ID_REG.test(req.params.id) && req.params.id;
    if (!id) {
        res.status(400).send({error: 'Missing or incorrect draft id'});
        return;
    }

    const {title, content} = req.body;
    if (!title || !content) {
        res.status(400).send({error: 'Missing title or content'});
    }

    const draft = await Draft
        .query()
        .where({id})
        .first();

    if (!draft) {
        res.status(404).send({error: 'Draft not found'});
        return;
    }

    if (draft.userId !== req.userInfo.id) {
        res.status(403).send({error: 'Authorization required'});
        return;
    }

    const result = await Draft
        .query()
        .where({id})
        .first()
        .update({
            title,
            content,
            updatedAt: new Date(),
        })
        .returning('updated_at');

    res.send(result);
};
