import {Request, Response} from 'express';
import {reportError} from '../../../core/utils';
import {tetherAccount, TetherResult} from '../../../services/wikidot-tethering.service';

export default async (req: Request, res: Response) => {
    try {
        if (req.user) {
            const {result} = await tetherAccount(req.user.id);

            switch (result) {
            case TetherResult.Ok:
                res.send({code: result});
                break;
            case TetherResult.PageNotFound:
                res.status(424).send({code: result});
                break;
            case TetherResult.AlreadyTethered:
                res.status(200).send({code: result});
                break;
            case TetherResult.WikidotUserAlreadyTethered:
                res.status(424).send({code: result});
                break;
            default:
                throw new Error('Unknown tether status');
            }
        } else {
            res.status(401).send('Unauthorized');
        }
    } catch (error) {
        res.status(500).send('Unhandled internal error, incident reported');
        reportError(error, {tags: {location: 'wikidot/tether-account'}});
    }
};
