import {NextFunction, Request, Response} from 'express';
import {reportError} from '../core/utils';
import {Branch} from '../models';


export default function branchResolverMiddleware(req: Request, res: Response, next: NextFunction) {
    const hostname = req.get('host');

    Branch
        .query()
        .select('*')
        .where({host: hostname})
        .first()
        .then((result: Branch) => {
            if (result) {
                req.branch = result;
                next();
            } else {
                req.log.warn(`Unknown branch for host "${hostname}"`);
                res.status(400).send('Unknown branch');
            }
        })
        .catch((error: Error) => {
            reportError(error, {message: 'Unhandled error during branch resolving'});
            res.status(500).send('Internal server error (branch resolving failure)');
        });
}
