import {NextFunction, Request, Response} from 'express';
import {reportError} from '../core/utils';
import {User} from '../models';


export default function userResolverMiddleware(req: Request, res: Response, next: NextFunction) {
    const userId = req.user && req.user.id;

    if (!userId) {
        next();
        return;
    }

    User
        .query()
        .select('*')
        .where({id: userId})
        .first()
        .then((user) => {
            if (user) {
                req.userInfo = user;
            }
            next();
        })
        .catch((error: Error) => {
            reportError(error, {message: 'Unhandled error during branch resolving'});
            res.status(500).send('Internal server error');
        });
}
