import {wk} from '../components/wikidot-kit';
import {User} from '../models';

const MIGRATION_WIKI_NAME = 'scp-migration';
const PAGE_NOT_FOUND_CODE = 406;

export enum TetherResult {
  Ok = 'Ok',
  PageNotFound = 'PageNotFound',
  AlreadyTethered = 'AlreadyTethered',
  WikidotUserAlreadyTethered = 'WikidotUserAlreadyTethered',
}

export async function tetherAccount(userId: string) {
    const pageName = `scp-id-${userId}`;

    try {
        const tetherPage = await wk.fetchPage(MIGRATION_WIKI_NAME, pageName);
        const author = tetherPage.created_by;

        const user = await User.query().select('*').where({id: userId}).first() as User;
        if (user.wikidotUid) {
            return {result: TetherResult.AlreadyTethered};
        }

        const existingUser = await User.query().select('*').where({username: author}).first();
        if (existingUser) {
            return {result: TetherResult.WikidotUserAlreadyTethered};
        }

        await User
            .query()
            .update({
                username: author,
                wikidotUid: -Math.ceil(Math.random() * 10e5),
            })
            .where({id: userId});

        return {result: TetherResult.Ok};
    } catch (error) {
        if (error.code === PAGE_NOT_FOUND_CODE) {
            return {result: TetherResult.PageNotFound};
        }
        throw error;
    }
}
