"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const objection_1 = require("objection");
var ClearanceLevel;
(function (ClearanceLevel) {
    ClearanceLevel["Guest"] = "guest";
    ClearanceLevel["User"] = "user";
    ClearanceLevel["Admin"] = "admin";
})(ClearanceLevel || (ClearanceLevel = {}));
const routes = [
    {
        name: 'main',
        path: '/',
    },
    {
        name: 'ping',
        path: '/ping',
    },
    {
        name: 'wikidot/random-page',
        path: '/wikidot_random_page',
    },
    {
        name: 'wikidot/api/tether-account',
        path: '/wikidot/api/tether-account',
        method: 'post',
    },
    {
        name: 'wikidot/api/random-page',
        path: '/api/random_page',
    },
    {
        name: 'wikidot/api/random-page',
        path: '/api/wikidot_random_page',
    },
    {
        name: 'wikidot/api/tags-list',
        path: '/_api/wikidot_tags_search/list',
    },
    {
        name: 'wikidot/api/tags-search',
        path: '/_api/wikidot_tags_search/find',
    },
    {
        name: 'wikidot/get-page',
        path: '/api/wikidot/pages/:wikiName/:pageName',
    },
    {
        name: 'drafts/list',
        path: '/api/drafts',
        clearance: ClearanceLevel.User,
    },
    {
        name: 'drafts/show',
        path: '/api/drafts/:id',
    },
    {
        name: 'drafts/create',
        path: '/api/drafts',
        method: 'post',
        clearance: ClearanceLevel.User,
    },
    {
        name: 'drafts/update',
        path: '/api/drafts/:id',
        method: 'post',
        clearance: ClearanceLevel.User,
    },
    {
        name: 'drafts/delete',
        path: '/api/drafts/:id',
        method: 'delete',
        clearance: ClearanceLevel.User,
    },
];
function userClearanceMiddleware(req, res, next) {
    if (req.userInfo) {
        next();
    }
    else {
        res.status(401).send({ error: 'Authentication required' });
    }
}
function initRoutes(app) {
    routes.forEach((route) => {
        const routeClearance = route.clearance || ClearanceLevel.Guest;
        const method = route.method || 'get';
        const routeHandler = require(`./controllers/${route.name}`).default;
        const routeMiddleware = [];
        if (routeClearance !== ClearanceLevel.Guest) {
            routeMiddleware.push(userClearanceMiddleware);
        }
        app[method](route.path, routeMiddleware, (req, res, next) => {
            Promise
                .resolve(routeHandler(req, res))
                .catch((error) => {
                if (error instanceof objection_1.ValidationError) {
                    return res.status(400).send({ error: 'Validation error', details: error.data });
                }
                return next(error);
            });
        });
    });
}
exports.default = initRoutes;
//# sourceMappingURL=routes.js.map