"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const wikidot_kit_1 = require("../components/wikidot-kit");
const models_1 = require("../models");
const MIGRATION_WIKI_NAME = 'scp-migration';
const PAGE_NOT_FOUND_CODE = 406;
var TetherResult;
(function (TetherResult) {
    TetherResult["Ok"] = "Ok";
    TetherResult["PageNotFound"] = "PageNotFound";
    TetherResult["AlreadyTethered"] = "AlreadyTethered";
    TetherResult["WikidotUserAlreadyTethered"] = "WikidotUserAlreadyTethered";
})(TetherResult = exports.TetherResult || (exports.TetherResult = {}));
async function tetherAccount(userId) {
    const pageName = `scp-id-${userId}`;
    try {
        const tetherPage = await wikidot_kit_1.wk.fetchPage(MIGRATION_WIKI_NAME, pageName);
        const author = tetherPage.created_by;
        const user = await models_1.User.query().select('*').where({ id: userId }).first();
        if (user.wikidotUid) {
            return { result: TetherResult.AlreadyTethered };
        }
        const existingUser = await models_1.User.query().select('*').where({ username: author }).first();
        if (existingUser) {
            return { result: TetherResult.WikidotUserAlreadyTethered };
        }
        await models_1.User
            .query()
            .update({
            username: author,
            wikidotUid: -Math.ceil(Math.random() * 10e5),
        })
            .where({ id: userId });
        return { result: TetherResult.Ok };
    }
    catch (error) {
        if (error.code === PAGE_NOT_FOUND_CODE) {
            return { result: TetherResult.PageNotFound };
        }
        throw error;
    }
}
exports.tetherAccount = tetherAccount;
//# sourceMappingURL=wikidot-tethering.service.js.map